package com.sf.web.dms.common.control;

package ..deTemp.1736263388257;

import com.sf.web.dms.common.bean.PointBean;
import com.sf.web.dms.common.dao.PMSDataClient;
import com.sf.web.dms.common.dao.RHDBClient;
import com.sf.web.dms.common.dao.RTHDBDao;
import com.sf.web.dms.common.service.ModelService;
import com.sf.web.dms.common.ws.ConsumerMngWebsocketService;
import com.sf.web.dms.common.ws.MsgProxyWebSocketService;
import com.smartframework.core.annotation.SmartComment;
import com.smartframework.core.cache.UserLoginCache;
import com.smartframework.core.dao.BasicJdbcDao;
import com.smartframework.core.dao.page.PagingBean;
import com.smartframework.core.i18n.I18n;
import com.smartframework.core.smart.SmartHelper;
import com.smartframework.core.smart.SmartView;
import com.smartframework.web.core.Constants;
import com.smartframework.web.core.bean.HeaderConfig;
import com.smartframework.web.core.control.BasicControl;
import com.smartframework.web.core.queryfilter.QueryFilter;
import com.smartframework.web.core.util.ExcelDataUtil;
import com.smartframework.web.core.util.I18nMessage;
import com.smartframework.web.core.util.ParameterUtils;
import com.smartframework.web.system.utility.service.SysQueryMngService;
import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

@SmartComment("A5000数据获取接口")
public class DataAccessControl extends BasicControl {
  private RTHDBDao rthDbDao = (RTHDBDao)SmartHelper.getBean("rthDbDao");
  
  private SysQueryMngService sysQueryMngService;
  
  private ModelService modelService;
  
  public ModelService getModelService() {
    return this.modelService;
  }
  
  public void setModelService(ModelService modelService) {
    this.modelService = modelService;
  }
  
  public SysQueryMngService getSysQueryMngService() {
    return this.sysQueryMngService;
  }
  
  public void setSysQueryMngService(SysQueryMngService sysQueryMngService) {
    this.sysQueryMngService = sysQueryMngService;
  }
  
  @SmartComment("按照字典名称返回字典项")
  public SmartView listMenusByName(String menuName) {
    if (ParameterUtils.isEmptyOrNull(menuName))
      return SmartView.ERROR(I18nMessage.paraEmptyMsg("菜单名称:menuName")); 
    return SmartView.SUCCESS(QueryFilter.NEW("SELECT ACTUAL_VALUE id,DISPLAY_VALUE description,MENU_MACRO_NAME MACRO_NAME FROM sys_menu WHERE").addStringFieldEqualCondition("MENU_NAME", menuName).queryForList());
  }
  
  @SmartComment("查询实时库点")
  public SmartView loadPointValue(List<String> pointIds, String fullTableName) {
    if (ParameterUtils.isEmptyOrNull(fullTableName))
      return SmartView.ERROR("必须指定实时库的表名称"); 
    if (this.rthDbDao == null)
      return SmartView.ERROR("rthDbDao 未定义"); 
    StringBuffer sqlBuffer = new StringBuffer("select id,description,value,status from " + fullTableName + " where ");
    for (String p : pointIds)
      sqlBuffer.append("id=" + p).append(" or "); 
    sqlBuffer.append("id=0");
    List<Map<String, Object>> list = this.rthDbDao.queryForList(sqlBuffer.toString());
    return (list == null) ? SmartView.ERROR("查询异常") : SmartView.SUCCESS(list);
  }
  
  @SmartComment("查询时序库点曲线趋势")
  public SmartView loadHistoryChartData(List<PointBean> pointList, Date startTime, Date endTime, Integer timeSpace) {
    if (this.rthDbDao == null)
      return SmartView.ERROR("rthDbDao 未定义"); 
    if (pointList == null || pointList.isEmpty())
      return SmartView.ERROR(I18n.paraEmptyMsg("pointList")); 
    if (startTime == null || endTime == null)
      return SmartView.ERROR(I18n.paraEmptyMsg("startTime,endTime")); 
    if (timeSpace == null || timeSpace.intValue() < 0)
      timeSpace = Integer.valueOf(0); 
    try {
      return SmartView.SUCCESS(RHDBClient.createChartData(this.rthDbDao, pointList, startTime, endTime, timeSpace));
    } catch (Exception e) {
      return SmartView.ERROR("访问时序库异常:" + e.getMessage());
    } 
  }
  
  @SmartComment("查询时序库点-按点集合返回")
  public SmartView loadHistoryDataMap(List<String> pointList, Date startTime, Date endTime, Integer timeSpace) {
    if (this.rthDbDao == null)
      return SmartView.ERROR("rthDbDao 未定义"); 
    if (pointList == null || pointList.isEmpty())
      return SmartView.ERROR(I18n.paraEmptyMsg("pointList")); 
    if (startTime == null || endTime == null)
      return SmartView.ERROR(I18n.paraEmptyMsg("startTime,endTime")); 
    if (timeSpace == null || timeSpace.intValue() < 0)
      timeSpace = Integer.valueOf(0); 
    try {
      return SmartView.SUCCESS(RHDBClient.loadHistoryDataBean(this.rthDbDao, pointList, startTime, endTime, timeSpace));
    } catch (Exception e) {
      return SmartView.ERROR("访问时序库异常:" + e.getMessage());
    } 
  }
  
  @SmartComment("按配置查询实时库")
  public SmartView loadDataByQueryId(String queryId, LinkedHashMap<String, Object> queryParameters, Integer pageIndex, Integer pageSize) {
    if (this.rthDbDao == null)
      return SmartView.ERROR("rthDbDao 未定义"); 
    if (ParameterUtils.isEmptyOrNull(queryId))
      return SmartView.ERROR("未指定查询"); 
    if (queryParameters == null)
      queryParameters = new LinkedHashMap<>(); 
    for (String key : queryParameters.keySet()) {
      if (queryParameters.get(key) == null)
        return SmartView.ERROR("查询参数中的数值不可以为空"); 
    } 
    try {
      for (String key : queryParameters.keySet()) {
        if (ParameterUtils.isNumeric(String.valueOf(queryParameters.get(key)))) {
          queryParameters.replace(key, Long.valueOf(String.valueOf(queryParameters.get(key))));
          continue;
        } 
        if (ArrayList.class.equals(queryParameters.get(key).getClass())) {
          List<?> list = (List)queryParameters.get(key);
          if (!list.isEmpty() && ParameterUtils.isNumeric(String.valueOf(list.get(0)))) {
            List<Long> newList = new ArrayList<>();
            for (Object o : list)
              newList.add(Long.valueOf(String.valueOf(o))); 
            queryParameters.replace(key, newList);
          } 
        } 
      } 
      if (ParameterUtils.isNotValidateId(pageSize)) {
        pageIndex = Integer.valueOf(1);
        pageSize = Integer.valueOf(-1);
      } 
      if (ParameterUtils.isNotValidateId(pageIndex))
        pageIndex = Integer.valueOf(1); 
      if (queryId.startsWith("CDB_"))
        return SmartView.PAGEDATA(this.sysQueryMngService.executeQuery(null, queryId, queryParameters, pageIndex, pageSize)).NOTFORMATDATE(); 
      if (queryId.startsWith("RTDB_"))
        return SmartView.PAGEDATA(this.sysQueryMngService.executeQuery((BasicJdbcDao)this.rthDbDao, queryId, queryParameters, pageIndex, pageSize)).NOTFORMATDATE(); 
      if (queryId.startsWith("PMS_")) {
        queryId = queryId.replace("PMS_", "");
        String sql = String.valueOf(queryParameters.get("sql"));
        if (!sql.toLowerCase().startsWith("select"))
          return SmartView.ERROR("SQL异常"); 
        return SmartView.SUCCESS(PMSDataClient.excuteUserClient(sql, queryParameters));
      } 
      return SmartView.ERROR("查询ID必须以CDB,RTDB,PMSDB作为前缀");
    } catch (Exception e) {
      return SmartView.ERROR(e.getMessage());
    } 
  }
  
  @SmartComment("根据设备表或容器表名称查询PMS台帐信息")
  public SmartView loadDevPmsInfo(String tableName, String filter, List<Long> idList) {
    if (ParameterUtils.isEmptyOrNull(tableName) || ParameterUtils.isEmptyOrNull(idList))
      return SmartView.ERROR("必须指定对象ID和表名称"); 
    return SmartView.SUCCESS(this.modelService.loadPmsInfo(tableName, filter, idList.get(0)));
  }
  
  public SmartView loadWindsByTransId(List<Long> devIds, String fullTableName) {
    if (ParameterUtils.isEmptyOrNull(fullTableName))
      return SmartView.ERROR("必须指定实时库的表名称"); 
    if (this.rthDbDao == null)
      return SmartView.ERROR("rthDbDao 未定义"); 
    StringBuffer sqlBuffer = new StringBuffer("select id,container_id from " + fullTableName + " where ");
    for (Long p : devIds)
      sqlBuffer.append("container_id= " + p).append(" or "); 
    sqlBuffer.append("id=0");
    List<Map<String, Object>> list = this.rthDbDao.queryForList(sqlBuffer.toString());
    return (list == null) ? SmartView.ERROR("查询异常") : SmartView.SUCCESS(list);
  }
  
  public SmartView loadFaultIndicatorByRelDevId(List<Long> devIds, String fullTableName) {
    if (!Constants.getBoolean("dms.faultIndicator.dynamic"))
      return SmartView.SUCCESS(new ArrayList()); 
    if (ParameterUtils.isEmptyOrNull(fullTableName))
      return SmartView.ERROR("必须指定实时库的表名称"); 
    if (this.rthDbDao == null)
      return SmartView.ERROR("rthDbDao 未定义"); 
    StringBuffer sqlBuffer = new StringBuffer("select id,related_dev_id,related_dev_id2 from " + fullTableName + " where ");
    for (Long p : devIds)
      sqlBuffer.append("related_dev_id = " + p).append(" or "); 
    sqlBuffer.append("id=0");
    List<Map<String, Object>> list = this.rthDbDao.queryForList(sqlBuffer.toString());
    return (list == null) ? SmartView.ERROR("查询异常") : SmartView.SUCCESS(list);
  }
  
  public SmartView descByQueryIdList(String tableName, List<Long> idList, Integer pageIndex, Integer pageSize) {
    QueryFilter queryFilter = new QueryFilter();
    if (!ParameterUtils.isEmptyOrNull(idList))
      queryFilter.addNumberFieldInCondition("e.id", idList); 
    if (pageSize == null || pageIndex == null)
      return SmartView.ERROR(I18n.message("error.parameter.empty", "分页参数{0}不能为空", new Object[] { "pageIndex,pageSize" })); 
    queryFilter.setPageInfo(pageSize, pageIndex);
    PagingBean page = this.modelService.queryRecords(tableName, queryFilter);
    return pageView(page);
  }
  
  @SmartComment("遥控操作")
  public SmartView remoteCtrl(String functionCode, Map<String, Object> params) {
    if (ParameterUtils.isEmptyOrNull(functionCode))
      return SmartView.ERROR(I18n.message("error.smartsys.remote.ctrl.code.required", "遥控操作的功能码不能为空")); 
    return UserLoginCache.authCheck(functionCode) ? SmartView.SUCCESS("执行成功") : SmartView.ERROR("当前用户:" + UserLoginCache.getSessionUser().getUserName() + "没有功能权限");
  }
  
  @SmartComment("查看WebSocket负载")
  public SmartView viewMsgProxyLoad() {
    Map<String, Object> msgProxyInfo = new HashMap<>();
    msgProxyInfo.put("wsMsgClientInfo", MsgProxyWebSocketService.wsMsgClientInfo());
    return SmartView.SUCCESS(msgProxyInfo);
  }
  
  @SmartComment("刷新MsgProxy远程连接")
  public SmartView refreshMsgProxy() {
    MsgProxyWebSocketService.refreshProxyClients();
    return viewMsgProxyLoad();
  }
  
  @SmartComment("查看消息处理列表")
  public SmartView listConsumerAgents() {
    return SmartView.SUCCESS(ConsumerMngWebsocketService.agentInfo());
  }
  
  @SmartComment("测试代理通讯消息")
  public SmartView testConsumer() {
    Map<String, Object> config = new HashMap<>();
    config.put("key1", "value1");
    ConsumerMngWebsocketService.sendConfigChangeMessage("test", config);
    ConsumerMngWebsocketService.sendCmdMessage("test", "test command");
    return SmartView.SUCCESS();
  }
  
  @SmartComment("测试Excel导出")
  public SmartView exportFormatXls() {
    List<HeaderConfig> headers = new ArrayList<>();
    headers.add(new HeaderConfig("id", "ID"));
    headers.add(new HeaderConfig("date", "日期", "center", "yyyy-MM-dd"));
    List<Map<String, Object>> list = new ArrayList<>();
    for (int i = 0; i < 10; i++) {
      Map<String, Object> row = new HashMap<>();
      row.put("id", Integer.valueOf(i + 10));
      row.put("date", new Date());
      list.add(row);
    } 
    try {
      ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
      ExcelDataUtil.createExcelByMapList(list, headers).write(outputStream);
      return SmartView.FileView(outputStream, "测试导出.xls");
    } catch (Exception e) {
      return SmartView.ERROR(I18n.message("error.excel.export", new Object[] { e.getMessage() }));
    } 
  }
  
  public SmartView rtdbQuery(String tableName, String columnNames, List<Object> inFieldValues, String fieldName) {
    return SmartView.SUCCESS(RHDBClient.queryRtdbByJNI(tableName, columnNames, inFieldValues, fieldName));
  }
}
